@@ -1,6 +1,6 @@
 <?php
 /**
- * Copyright 2007-2016 Horde LLC (http://www.horde.org/)
+ * Copyright 2007-2017 Horde LLC (http://www.horde.org/)
  *
  * See the enclosed file COPYING for license information (LGPL). If you
  * did not receive this file, see http://www.horde.org/licenses/lgpl21.
@@ -202,7 +202,7 @@ class Horde_Memcache implements Serializable
 
         if (isset($this->_params['logger'])) {
             $this->_logger = $this->_params['logger'];
-            $this->_logger->log('Connected to the following memcache servers:' . implode($this->_servers, ', '), 'DEBUG');
+            $this->_logger->log('Connected to the following memcache servers:' . implode(', ', $this->_servers), 'DEBUG');
         }
     }
 
